<?php

declare(strict_types=1);

namespace Pheanstalk;

/**
 * An exception originating from the Pheanstalk package.
 * @extensible
 */
class Exception extends \Exception
{
}
